#
# spec file for package python-mkdocs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-mkdocs
Version:        1.6.1
Release:        1.3
Summary:        Project documentation with Markdown
License:        BSD-2-Clause
URL:            https://www.mkdocs.org
Source:         https://github.com/mkdocs/mkdocs/archive/%{version}.tar.gz#/mkdocs-%{version}.tar.gz
BuildRequires:  %{python_module Babel >= 2.9.0}
BuildRequires:  %{python_module Jinja2 >= 2.11.1}
BuildRequires:  %{python_module Markdown >= 3.3.6}
BuildRequires:  %{python_module MarkupSafe}
BuildRequires:  %{python_module PyYAML >= 5.1}
BuildRequires:  %{python_module click >= 7.0}
BuildRequires:  %{python_module ghp-import >= 1.0}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module importlib_metadata if python-base < 3.10}
BuildRequires:  %{python_module mergedeep >= 1.3.4}
BuildRequires:  %{python_module mkdocs-get-deps >= 0.2.0}
BuildRequires:  %{python_module packaging >= 20.5}
BuildRequires:  %{python_module pathspec >= 0.11.1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyyaml_env_tag >= 0.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module watchdog >= 2.0}
BuildRequires:  fdupes
BuildRequires:  fontawesome-fonts
BuildRequires:  fontawesome-fonts-web
BuildRequires:  python-rpm-macros
Requires:       fontawesome-fonts
Requires:       fontawesome-fonts-web
Requires:       python-Jinja2 >= 2.11.1
Requires:       python-Markdown >= 3.3.6
Requires:       python-MarkupSafe
Requires:       python-PyYAML >= 5.1
Requires:       python-click >= 7.0
Requires:       python-ghp-import >= 1.0
Requires:       python-importlib_metadata
Requires:       python-mergedeep >= 1.3.4
Requires:       python-mkdocs-get-deps >= 0.2.0
Requires:       python-packaging >= 20.5
Requires:       python-pathspec >= 0.11.1
Requires:       python-pyyaml_env_tag >= 0.1
Requires:       python-watchdog >= 2.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
Suggests:       python-babel
BuildArch:      noarch
%python_subpackages

%description
MkDocs is a static site generator for building project documentation.
Documentation source files are written in Markdown, and configured
with a single YAML configuration file.

%prep
%autosetup -n mkdocs-%{version}

# Get rid of shebangs.
find . -type f -name "*.py" -exec sed -i '/#!\/usr\/bin\/env/d' {} +
find . -type f -name "*.svg" -exec chmod -x {} +

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/mkdocs

# unbundle fontawesome where possible
if [ -f %{buildroot}%{python_sitelib}/mkdocs/themes/mkdocs/css/font-awesome.min.css ]; then
  if [ -f %{_datadir}/fontawesome-web/css/fontawesome.min.css ]; then
    rm %{buildroot}%{python_sitelib}/mkdocs/themes/mkdocs/css/font-awesome.min.css
    ln -sf %{_datadir}/fontawesome-web/css/fontawesome.min.css %{buildroot}%{python_sitelib}/mkdocs/themes/mkdocs/css/font-awesome.min.css
  fi
fi
for filetype in eot svg ttf woff woff2; do
  for theme in mkdocs readthedocs; do
    [ -f %{_datadir}/fontawesome-web/webfonts/fa-regular-400.$filetype ] || continue
    [ -f %{buildroot}%{python_sitelib}/mkdocs/themes/$theme/fonts/fontawesome-webfont.$filetype ] || continue
    rm %{buildroot}%{python_sitelib}/mkdocs/themes/$theme/fonts/fontawesome-webfont.$filetype
    ln -sf %{_datadir}/fontawesome-web/webfonts/fa-regular-400.$filetype %{buildroot}%{python_sitelib}/mkdocs/themes/$theme/fonts/fontawesome-webfont.$filetype
  done
done

# inconsistent permissions prohibited fdupes from being effective
find %{buildroot} -type f "(" -name "*.eot" -o -name "*.ttf" -o \
	-name "*.woff" ")" -exec chmod a-x {} +

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
rm -vf mkdocs/tests/gh_deploy_tests.py
rm -vf mkdocs/tests/config/config_tests.py
rm -vf mkdocs/tests/cli_tests.py
rm -vf mkdocs/tests/config/base_tests.py
%pyunittest discover -p '*tests.py' -v mkdocs --top-level-directory .

%post
%python_install_alternative mkdocs

%postun
%python_uninstall_alternative mkdocs

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/mkdocs
%{python_sitelib}/mkdocs
%{python_sitelib}/mkdocs-%{version}*-info

%changelog
* Mon Sep  9 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.6.1:
  * Fixed
  - Fix build error when environment variable SOURCE_DATE_EPOCH=0
    is set. #3795
  - Fix build error when mkdocs_theme.yml config is empty. #3700
  - Support python -W and PYTHONWARNINGS instead of overriding
    the configuration. #3809
  - Support running with Docker under strict mode, by removing
    0.0.0.0 dev server warning. #3784
  - Drop unnecessary changefreq from sitemap.xml. #3629
  - Fix JavaScript console error when closing menu dropdown.
    [#3774]
  - Fix JavaScript console error that occur on repeated clicks.
    [#3730]
  - Fix JavaScript console error that can occur on dropdown
    selections. #3694
  * Added
  - Added translations for Dutch. #3804
  - Added and updated translations for Chinese (Simplified).
    [#3684]
* Thu Apr 25 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.6.0:
  Big update, see full changelog at
  https://github.com/mkdocs/mkdocs/releases/tag/1.6.0
  * Deprecations
  - Python 3.7 is no longer supported, Python 3.12 is officially
    supported. Context: #3429
  - The theme config file mkdocs_theme.yml no longer executes
    YAML tags. Context: #3465
  - The plugin event on_page_read_source is soft-deprecated
    because there is always a better alternative to it (see the
    new File API or just on_page_markdown, depending on the
    desired interaction).
  - When multiple plugins/hooks apply this event handler, they
    trample over each other, so now there is a warning in that
    case.
  - See documentation. Context: #3503
  * API deprecations
  - It is no longer allowed to set File.page to a type other than
    Page or a subclass thereof. Context: #3443 - following the
    deprecation in version 1.5.3 and #3381.
  - Theme._vars is deprecated - use theme['foo'] instead of
    theme._vars['foo']
  - utils: modified_time(), get_html_path(), get_url_path(),
    is_html_file(), is_template_file() are removed. path_to_url()
    is deprecated.
  - LiveReloadServer.watch() no longer accepts a custom callback.
* Tue Sep 19 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 1.5.3:
  * Fix mkdocs serve sometimes locking up all browser tabs when
    navigating quickly (#3390)
  * Add many new supported languages for "search" plugin - update
    lunr-languages to 1.12.0 (#3334)
  * Bugfix (regression in 1.5.0): In "readthedocs" theme the
    styling of "breadcrumb navigation" was broken for nested pages
    (#3383)
  * Built-in themes now also support Chinese (Traditional, Taiwan)
    language (#3370)
  * Plugins can now set File.page to their own subclass of Page.
    There is also now a warning if File.page is set to anything
    other than a strict subclass of Page. (#3367, #3381)
  * Note that just instantiating a Page sets the file
    automatically, so care needs to be taken not to create an
    unneeded Page.
* Fri Aug  4 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 1.5.2:
  * Bugfix (regression in 1.5.0): Restore functionality of
  - -no-livereload. (#3320)
  * Bugfix (regression in 1.5.0): The new page title detection
    would sometimes be unable to drop anchorlinks - fix that.
    (#3325)
  * Partly bring back pre-1.5 API: extra_javascript items will once
    again be mostly strings, and only sometimes ExtraStringValue
    (when the extra script functionality is used).
  * Plugins should be free to append strings to
    config.extra_javascript, but when reading the values, they must
    still make sure to read it as str(value) in case it is an
    ExtraScriptValue item. For querying the attributes such as
    .type you need to check isinstance first. Static type checking
    will guide you in that. (#3324)
* Tue Aug  1 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 1.5.1:
  * Bug fixes
  - Bugfix (regression in 1.5.0): Make it possible to treat
    ExtraScriptValue as a path. This lets some plugins still work
    despite the breaking change.
  - Bugfix (regression in 1.5.0): Prevent errors for special
    setups that have 3 conflicting files, such as index.html,
    index.md and README.md (#3314)
* Thu Jul 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 1.5.0:
  * very long changelog that can be found here:
    https://github.com/mkdocs/mkdocs/releases/tag/1.5.0
  * Bug fixes
  - Relative paths in the nav can traverse above the root
    Regression in 1.2 - relative paths in the nav could no longer
    traverse above the site's root and were truncated to the
    root. Although such traversal is discouraged and produces a
    warning, this was a documented behavior. The behavior is now
    restored.
  - MkDocs can accept the config from stdin
    This can be used for config overrides on the fly. See updated
    section at the bottom of Configuration Inheritance.
    The command to use this is mkdocs build -f -. In previous
    versions doing this led to an error.
* Thu Jul  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 1.4.3:
  * Bugfix: for the hooks feature, modules no longer fail to load
    if using some advanced Python features like dataclasses (#3193)
  * Bugfix: Don't create None sitemap entries if the page has no
    populated URL - affects sites that exclude some files from
    navigation (07a297b)
  * "readthedocs" theme:
  - Accessibility: add aria labels to Home logo (#3129) and
    search inputs (#3046)
  - "readthedocs" theme now supports hljs_style: config, same as
    "mkdocs" theme (#3199)
  * Translations:
  - Built-in themes now also support Indonesian language (#3154)
  - Fixed zh_CN translation (#3125)
  - tr_TR translation becomes just tr - usage should remain
    unaffected (#3195)
* Thu Jul  6 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Mar 17 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 1.4.2:
  * Officially support Python 3.11 (#3020)
  - Note: Simply upgrading to Python 3.11 can cut off 10-15%% of
    your site's build time.
  * Support multiple instances of the same plugin (#3027)
  * If a plugin is specified multiple times in the list under the
    plugins: config, that will create 2 (or more) instances of the
    plugin with their own config each.
  * Previously this case was unforeseen and, as such, bugged.
  * Now even though this works, by default a warning will appear
    from MkDocs anyway, unless the plugin adds a class variable
    supports_multiple_instances = True.
  * Bugfix (regression in 1.4.1): Don't error when a plugin puts a
    plain string into warnings (#3016)
  * Bugfix: Relative links will always render with a trailing
    slash (#3022)
  * Previously under use_directory_urls, links from a sub-page to
    the main index page rendered as e.g. `<a href="../..">` even
    though in all other cases the links look like
    `<a href="../../">`. This caused unwanted behavior on some
    combinations of Web browsers and servers. Now this special-case
    bug was removed.
  * Built-in "mkdocs" theme now also supports Norwegian language
    (#3024)
  * Plugin-related warnings look more readable (#3016)
- adjust spec file to build with hatch and pyproject.toml
- update to 1.4.1:
  * Support theme-namespaced plugin loading (#2998)
  * Plugins' entry points can be named as 'sometheme/someplugin'.
    That will have the following outcome:
  - If the current theme is 'sometheme', the plugin
    'sometheme/someplugin' will always be preferred over
    'someplugin'.
  - If the current theme isn't 'sometheme', the only way to use
    this plugin is by specifying plugins: [sometheme/someplugin].
  * One can also specify plugins: ['/someplugin'] instead of
    plugins: ['someplugin'] to definitely avoid the
    theme-namespaced plugin.
  * Bugfix: mkdocs serve will work correctly with non-ASCII paths
    and redirects (#3001)
  * Windows: 'colorama' is now a dependency of MkDocs, to ensure
    colorful log output (#2987)
  * Plugin-related config options have more reliable validation
    and error reporting (#2997)
  * Translation sub-commands of setup.py were completely dropped.
    See documentation [1] [2] for their new replacements (#2990)
  * The 'mkdocs' package (wheel and source) is now produced by
    Hatch build system and pyproject.toml instead of setup.py
    (#2988)
- update to 1.4.0:
  * Large update, full changelog at
    https://github.com/mkdocs/mkdocs/releases/tag/1.4.0
* Mon Feb 27 2023 Matej Cepl <mcepl@suse.com>
- Enable tests
- Don't use fdupes -s, it hurts.
* Sun Sep  4 2022 Elisei Roca <eroca@mailbox.org>
- fix fontawesome unbundling for Leap
* Mon Aug 29 2022 Elisei Roca <eroca@mailbox.org>
- Update to version 1.3.1 (2022-07-19)
  * Release 1.3.1 (#2895)
  * Requirements: pin Markdown version to <3.4 (#2893)
  * When a Markdown extension fails to load, print its name and traceback (#2894)
  * Italian translation for mkdocs and readthedocs themes (#2860)
  * Docs: `site_url` is optional (#2863)
  * Check only for uppercase README.md file (#2852)
  * Clean up code style (#2825)
  * Fix typo in configuration.md (#2844)
  * Added an extra space to the readthedocs theme breadcrumbs (#2810)
- update fontawesome unbundling section in spec file
* Sun Jun 12 2022 Elisei Roca <eroca@mailbox.org>
- update to version 1.3.0 (2022-03-26)
  * Release 1.3.0 (#2806)
  * Revert to disregarding the mount path for /livereload/ endpoint (#2804)
  * Ensure that the `edit_uri` option does not modify the `repo_url` (#2733)
  * Revert "SubConfig now catches failures and warnings (#2710)"
  * Prevent XSS searching in builtin themes (#2791)
  * SubConfig now catches failures and warnings (#2710)
  * Add Persian (fa) translation to the default themes (#2787)
  * Make Jinja2 errors and OSErrors produce a clearer message (#2801)
  * Add --no-history option to not push parent history for gh_deploy (#2594)
  * Bump importlib_metadata to at least 4.3 to support Python 3.10 (#2802)
  * dev-guide: document page.file (#2763)
  * add GitHub URL for PyPi (#2785)
  * Compatibility with Jinja2 3.1.0 (#2800)
  * Fix documentation error in Developing Themes (#2781)
  * Pin MarkupSafe to <= 2.0.1 to support Jinja2 in minimum requirements (#2778)
  * Docs: fix relative link (#2756)
  * Fix PyPy version in MacOS CI workflow (#2755)
  * Fix imports to get tests passing (#2751)
  * Don't inject javascript poll script if livereload is disabled (#2742)
  * Move livereload endpoint under the mount path (#2740)
  * Don't define __ne__ methods, they're implicit since Py3 (#2735)
  * Declare support for Python 3.10 (#2617)
  * Don't import unused commands (#2714)
  * Reuse Jinja2 `tojson` builtin filter (#2713)
  * Drop needless assert from `FilesystemObject` config option (#2712)
  * Update ja translation for readthedocs theme (#2708)
  * Update brazilian portuguese translation for readthedocs Theme (#2705)
  * Update readthedocs theme French translation (#2699)
  * Update Spanish translation for Readthedocs theme (#2698)
  * Allow CI to run when pushing to a branch (#2439)
  * Turn the deprecated 'pages' config into an error on use (#2652)
  * Recursively validate `Nav` config option types (#2680)
  * Provide german locale file for readthedocs theme (#2633)
  * zh_CN: Update the translation of readthedocs (#2673)
  * Support custom directories to watch when running mkdocs serve (#2642)
  * Upgrade readthedocs theme to v1.0.0 (#2585)
  * Remove duplicated sentences in docs/deploying (#2667)
  * Add latest members of MkDocs maintenance team (#2661)
  * Fix typo (#2663)
  * Fix typo `mkdocs-theme.yml` (`mkdocs_theme.yml`) (#2654)
  * Modernize usages of assertRaises in tests (#2653)
  * Remove line length limit from Markdown documents (#2626)
  * Fix mistake in docs about nav configuration (#2636)
  * Update codebase to Python >= 3.6 (#2612)
  * Rewrite `test_build_page_empty` test (#2613)
  * Refactor `Nav` config option (#2622)
- changes in version 1.2.4 (2022-03-26)
  * Release 1.2.4 (#2805)
  * Compatibility with Jinja2 3.1.0 (#2800)
* Wed Nov 17 2021 Elisei Roca <eroca@mailbox.org>
- do not build for python2; mkdocs is python3-only since 1.1
- update dependencies and add all also as BuildRequires to always deliver an
  installable package
- update to version 1.2.3 (2021-10-12)
  https://github.com/mkdocs/mkdocs/blob/1.2.3/docs/about/release-notes.md
  * Built-in themes now also support these languages:
  * Simplified Chinese (#2497)
  * Japanese (#2525)
  * Brazilian Portuguese (#2535)
  * Spanish (#2545, previously #2396)
  * Third-party plugins will take precedence over built-in plugins with the same
    name (#2591)
  * Bugfix: Fix ability to load translations for some languages:
    core support (#2565) and search plugin support with fallbacks (#2602)
  * Bugfix (regression in 1.2): Prevent directory traversal in the dev server
    (#2604)
  * Bugfix (regression in 1.2): Prevent webserver warnings from being treated as
    a build failure in strict mode (#2607)
  * Bugfix: Correctly print colorful messages in the terminal on Windows (#2606)
  * Bugfix: Python version 3.10 was displayed incorrectly in `--version` (#2618)
  * Other small improvements
    see commit log (https://github.com/mkdocs/mkdocs/compare/1.2.2...1.2.3).
- changes in 1.2.2 (2021-07-18)
  * Bugfix (regression in 1.2): Fix serving files/paths with Unicode characters
    (#2464)
  * Bugfix (regression in 1.2): Revert livereload file watching to use polling
    observer (#2477)
  * Revert from 1.2: Remove the requirement of a `site_url` config and the
    restriction on `use_directory_urls` (#2490)
  * Bugfix (regression in 1.2): Don't require trailing slash in the URL when
    serving a directory index in `mkdocs serve` server (#2507)
  * Bugfix: Fix `gh_deploy` with config-file in the current directory (#2481)
  * Bugfix: Fix reversed breadcrumbs in "readthedocs" theme (#2179)
  * Allow "mkdocs.yaml" as the file name when '--config' is not passed (#2478)
  * Stop treating ";" as a special character in URLs: urlparse -> urlsplit (#2502)
  * Improve build performance for sites with many pages
    (partly already done in 1.2) (#2407)
- changes in 1.2.1 (2021-06-09)
  * Bugfix (regression in 1.2): Ensure 'gh-deploy' always pushes.
- changes in 1.2 (2021-06-04)
  * Support added for Theme Localization (#2299)
  * Support added for Environment Variables in the configuration file (#1954)
  * Support added for Configuration Inheritance (#2218)
  * Update `gh-deploy` command (#2170)
  * Rework auto-reload and HTTP server for `mkdocs serve` (#2385)
  * Offset the local site root according to the sub-path of the `site_url` (#2424)
  * A `build_error` event was added (#2103)
  * Three new exceptions: BuildError PluginError and Abort (#2103)
  * Search Indexing Strategy configuration
  * Backwards incompatible changes in 1.2
    https://github.com/mkdocs/mkdocs/blob/1.2/docs/about/release-notes.md?plain=1#L160
  * Other changes and additions, bugfixes in 1.2
    https://github.com/mkdocs/mkdocs/blob/1.2/docs/about/release-notes.md?plain=1#L230
* Sat Aug 14 2021 Jan Engelhardt <jengelh@inai.de>
- Trim conjecture from description. Use multi-file find -exec.
- Make fdupes actually functional.
* Wed May 19 2021 Matthias Mailänder <mailaender@opensuse.org>
- update to version 1.1.2
- unbundled font awesome
* Fri Sep 14 2018 ecsos@opensuse.org
- update to 1.0.4
  - Bugfix: Ignore absolute links in Markdown (#1621).
- changes from 1.0.3
  - Bugfix: Warn on relative paths in navigation (#1604).
  - Bugfix: Handle empty theme_config.yml files correctly (#1602).
- changes from 1.0.2
  - Bugfix: Provide absolute base_url to error templates (#1598).
- changes from 1.0.1
  - Bugfix: Prevent page reload when [Enter] is pressed in search
    box (#1589).
  - Bugfix: Avoid calling search until all assets are ready
  (#1584).
  - Bugfix: Exclude README.md if index.md is present (#1580).
  - Bugfix: Fix readthedocs theme navigation bug with homepage
    (#1576).
- changes from 1.0.0
  Internal handling of pages, files and navigation has been
  completely refactored. See:
  https://www.mkdocs.org/about/release-notes/#version-10-2018-08-03
* Tue Jul  3 2018 ecsos@opensuse.org
- initial version 0.17.4
